{% extends "planet/base.html" %}
{% load i18n pagination_tags %}

{% block extra_head %}
    <meta name="title" content="{% trans 'Authors for tag' %} {{ tag }}- {{ site.name }}" />
    <meta name="description" content="{% trans 'Authors for tag' %} {{ tag }} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block breadcrumb_section %}
    <li><a href="{% url 'planet.views.tags_cloud' %}">Tags</a> <span class="divider">/</span></li>
    <li><a href="{% url 'planet.views.tag_detail' tag.name %}">{{ tag }}</a> <span class="divider">/</span></li>
{% endblock %}
{% block breadcrumb_detail %}<li class="active">{% trans 'Authors' %}</li>{% endblock %}

{% block content %}
<h2>{% trans 'Authors talking about' %} {{ tag }}</h2>
<div class="authors">
    {% autopaginate authors 40 %}
    {% for author in authors %}
        <p>
            <a class="nombre" href="{% url 'planet_by_tag_author_detail' author.pk tag.name %}" title="{{ author.name }}">
                {{ author.name }}
            </a>
        </p>
    {% endfor %}
    {% paginate %}
</div>
{% endblock %}

{% block right_column %}
{% endblock %}
