{% extends "planet/base.html" %}
{% load i18n pagination_tags %}

{% block extra_head %}
    <meta name="title" content="{% trans 'Feeds for tag' %} {{ tag }}- {{ site.name }}" />
    <meta name="description" content="{% trans 'Feeds for tag' %} {{ tag }} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block breadcrumb_section %}
    <li><a href="{% url 'planet.views.tags_cloud' %}">Tags</a> <span class="divider">/</span></li>
    <li><a href="{% url 'planet.views.tag_detail' tag.name %}">{{ tag }}</a> <span class="divider">/</span></li>
{% endblock %}
{% block breadcrumb_detail %}<li class="active">{% trans 'Blog Feeds' %}</li>{% endblock %}

{% block content %}
<h2>{% trans 'Feeds talking about' %} {{ tag }}</h2>
<div class="feeds list">
    {% autopaginate feeds_list 40 %}
    {% for feed in feeds_list %}
        <p>
            <a href="{{ feed.feed_url }}" title="{% trans 'Subscribe to feed of' %} {{ feed.title }}">
                <img src="{{ MEDIA_URL }}images/feed.png" alt="Feed">
            </a>
            <a class="nombre" href="{% url 'planet_by_tag_feed_detail' feed.pk tag.name %}" title="{{ feed.title }}">
                {{ feed.title }}
            </a>
        </p>
    {% endfor %}
    {% paginate %}
</div>
{% endblock %}
