{% extends "planet/base.html" %}
{% load i18n pagination_tags planet_tags %}

{% block head_title %}{% trans 'Authors list' %} - {{ block.super }}{% endblock %}
{% block extra_head %}
    <meta name="title" content="{% trans 'Authors list' %} - {{ site.name }}" />
    <meta name="description" content="{% trans 'Authors list' %} - {{ site.name }}" />
    <meta name="robots" content="noindex, follow" />
{% endblock %}

{% block breadcrumb_section %}<li class="active">{% trans 'Blog Authors' %}</li>{% endblock %}

{% block content %}
<h2>{% trans "Authors" %}</h2>
<ul class="author list">
    {% autopaginate authors_list 20 %}
    {% for author in authors_list %}
        <li>
            <h3>
                <a class="nombre" href="{{ author.get_absolute_url }}" title="{% trans 'Author:' %} {{ author.name }}">
                    {{ author.name }}
                </a>
            </h3>
        </li>
        {% feeds_for_author author %}
    {% endfor %}
    {% paginate %}
</ul>
{% endblock %}
