{% extends 'site_base.html' %}
{% load i18n tagging_tags planet_tags %}

{% block extra_head %}
    <meta name="title" content="{{ site.name }}" />
    <meta name="robots" content="index, follow" />
    <meta name="generator" content="django-planet http://github.com/matagus/django-planet/tree">
    <link rel="alternate" type="application/rss+xml" title="{{ site.name }} - RSS 2.0 Feed" href="{% url 'planet_rss_feed' %}" />
    <meta name="robots" content="index, follow" />
{% endblock %}

{% block search %}
    <form name="search_form" id="search_form" action="{% url planet_search %}" method="GET">
        <label>{% trans 'Search in' %}</label>
        {{ search_form }}
        <button name="search" value="go">{% trans 'ok' %}</button>
    </form>
{% endblock %}

{% block right_column %}
    {% tag_cloud_for_model planet.Post as tags_cloud with steps=7 min_count=5 distribution=log %}
    {% include 'planet/tags/blocks/cloud.html' %}
    {% include 'planet/feeds/blocks/syndication_block.html' %}
{% endblock %}

{% block footer %}
    <p class="text-right">{% blocktrans %}A <a href="http://github.com/matagus/django-planet/tree" title="django-planet Powered">django-planet</a> powered site{% endblocktrans %}</p>
    {{ block.super }}
{% endblock %}
